# 区块链不能做什么
但凡提到区块链的文章，都会强调“去中心化”、“不可篡改”等特(xue)性(tou)来吸人眼球。仿佛用区块链就能在不久的将来构建一个理想的乌托邦，但是拥有这么多特性的区块链到底怎么来构建这个乌托邦，却没人能说得清楚。毕竟现在的行业还处于初期探索，大部分注意力都集中在技术层面，技术尚未成熟大家就想要抢占市场，难免会不愿意承认“看不到方向”。若非要回答这个问题，总有人能说出一些看似合理的应用场景，但大多数经不起推敲，更没有验证。诚然，落地这事不能一味地钻研技术，应用场景、发展方向、经营管理模式等都是需要考虑的方向。这里就目前区块链的一些应用场景展开一些讨论，并非说区块链不能在这些领域有所应用，更多地是指出一些很多人不愿意提但又绕不开的问题。

![](https://github.com/yjjnls/awesome-blockchain/blob/master/Basic/img/blockchain-jesus.png)

首先我们需要弄清楚一个容易被混淆的问题：[基于区块链开发的应用真的能“去中心化”、“防篡改”如此这般安全么？](https://www.zhihu.com/question/270698341)   

比特币、以太坊等数字货币为什么能实现所谓的“去中心化”与“不可篡改”呢？其实这里可以从区块链的本质来看， **`区块链的本质和基础是分布式账本以及确保所有结点都彼此充分一致的安全机制。`** 也就是人人都持有账本，才能防止个别人的篡改，这就是去中心化。 **所以可说去中心化、不可篡改、安全等特性都是关联在一起的，一个特性不能满足，其余特性也就被攻破了。** 那么是不是大家都持有账本，就是真的防止篡改了呢？显然不是，以比特币为例，其能做到防篡改是因为   

1.  挖矿的算力和实体电力成本挂钩，即使是51%攻击，也会无利可图，这是利用经济学上的博弈来牵制作弊篡改行为；
2.  比特币系统（注意这里不是指比特币）由无数的结点构成，这些结点大部分都是矿机，而且是24小时不停地工作。

我们来详细分析一下，第一点是因为中本聪设计比特币时采用了POW共识，并且制订了一系列的奇葩规定，使得挖矿难度大，成本高，这点可以归结为区块链的设计，要提高作弊成本，使得作弊无利可图。而第二点看似无关紧要，其实是比较关键的，试想一下，如果大家有账本，但是都不去记账，比如某一时刻大部分矿机坏了，这时全网算力就会大大下降，那么作弊所需要的算力成本也就大大下降，超过了博弈平衡，那么作弊行为变得有利可图，也就无法收场了。再举个简单的例子，比如你根据网上的教程开发了一个区块链应用，调试的时候其实就你本地一个结点，结果中途发现了bug或者崩溃了，那么就得改了重来，这其实就是一种篡改，因为在你本地篡改的成本很低。所以第二点要保证有大量在线结点，且要设计合理的 **共识机制**进行经济制约。

简单地说区块链防篡改，那肯定是不对的，要依据其具体设计与实现来判断。而且分叉作为一种链上治理的手段，和篡改行为在本质上是相同的，只是执行方不一样，就像孔乙己说：

>读书人的事能叫偷吗？

我们再来看看区块链的去中心化，**区块链能提供信任机制的本质是将数据内容的所有权分散给用户，且在一定程度上不能篡改（这也是基于数据权利分散的特性）。** 这通常适用于小型团体或者不同机构之间来建立信任机制，如果由单一有背书的大公司来提供服务，未必需要区块链。这些数据可以是金融数据或者社交数据或者其他。   

而数据分散的形式其实有两种，第一种是比特币和以太坊为代表的区块链1.0和2.0技术，所有用户都可以无门槛地加入结点，结点用户分布于全球每个角落，权利分散到每一个用户手中，从这一点上来看，这确实是名副其实的“全面去中心化”。但是其缺点也显而易见，那就是全球的用户都达成共识，所需要的时间非常长，作为公链来说，TPS非常低，无法进行商业应用。

|               | BTC |  ETH | EOS      | MIOTA    | BTS  | Cardano |
| :------------ | --: | :--: | -------- | -------- | ---- | ------- |
| 共识机制          | POW |  POW | DPOS+BFT | MCMC+POW | DPOS | POS     |
| 每秒事务处理量/TPS   | 5~7 | 7~14 | 1M (理论上) | 1000+    | 3300 | unknown |
| 总供应量/Millions |  21 |  可定增 | 1000     | 2780     | 3600 | 45000   |


第二种是区块链3.0技术（比如EOS）和联盟链，EOS在全球有21个超级结点，只有这21个超级结点进行记账。与比特币和以太坊的结点数量相比，21个结点达成共识所需的时间可以做到非常短，链的TPS也可以做到很高。联盟链用于不同企业和机构之间的账本同步，结点数量也是有限的，所以TPS才能提高。区块链3.0和联盟链的模型是一致的，只不过一个是公链，一个是联盟链，另外共识协议和细节处理也不同。他们的特点都是链的结点数量有限，而且要达到一定的门槛才能成为结点，所以这种“去中心化”又被称为 **“弱中心化”**。

同时，我们再进一步看，EOS在全球有21个超级结点，这和一个大公司在全球部署21个结点进行数据同步，从模型上来看没有多大区别，只是EOS的结点属于不同的结构。所以从这一点来看，**目前能够进行商业应用的区块链技术更多地是基于传统分布式技术的一些升级，`并不具有革命性`；而真正理想化的“全面去中心化”、点对点交易的理念，很难很难实现**（比特币其实也是中心化的，被五大矿池操纵，普通用户虽然可以参与，但是基本不起作用）。

同样，区块链作为一种数据库，去中心化一定是比中心化低效的，这也导致 **要达到同样的商用效果，区块链比传统分布式技术的成本更高**。只有在去中心化所带来的价值提升远大于效率的牺牲和成本的增加，才是有意义的，但在不用区块链也能很好运作的一些领域，加上区块链是否真的有必要，值得思考！

明白了上面这些，再来看具体领域的应用，分析起来路就会更加清晰。

## 公示公证

> 区块链世界目前还是现实世界的「平行宇宙」版本。

区块链可以保证链上数据的真实、透明、不可篡改，这里的“真实”指的是数据是原始的，没有被篡改过；但是如何保证上链数据在现实生活中的真实合法性呢？

比如现在流行的食品溯源，如何保证一只鸡是纯天然散养的？如何保证没有喂养激素？如果最后购买的是宰杀后的鸡，那宰杀过程的卫生如何保障？

现有做法是将喂养记录上链，那如何保证记录的真实性呢？还有运输、宰杀过程如何生成有效的数据上链呢？  
如果换做是蔬菜呢？每只鸡都可以有记录，难道每棵菜也有自己的编号？  
再比如一些加工食品，包装上都会有检验合格的信息，区块链可以保证每一步的加工检验数据上链后不会被篡改，但无法保证上链的这些记录都是真的。

这些数据的共同特点是数据源都在线下，而无法保证上链数据真实有效的根本原因在于 **参与者的信息化程度过低**。  

假设我们可以实时监控供应链上所有的货物处理过程，甚至账款的流转，那不管用不用区块链，都可以由某个第三方，如银行对供应商进行授信。但如果没有，那 **首先要解决的问题是信息化**，比如食品供应链的每个环节用互联网工具去记录，保证真实数据，还要打通整个行业的信息系统。这才是需要解决的核心问题，解决了核心问题，区块链才能真正地发挥作用。

## 通证经济

Token（通证）作为一种权益，代表资本市场的运作方式。Token可以分为基础设施型、金融型、商业垂直生态型等，其本质都代表了债券和股权。但不管是债权还是股权都有 **一个“不破产”的先决条件，就是发行经济主体的“有用”，而不是稀缺性（如总量限定，资本管制）决定了 Token 的价值，是有了价值才稀缺**。

比如在国外非常流行的REITs，它与房产挂钩，且有大型机构和企业做背书，这保障了其稳定与流通性。而且REITs也没有用区块链实现，大多数ICO项目只是希望首次发行Token获得融资来维持项目运转或者套现跑路。

另一方面，除了金融型Token，其余类型的Token都会与实物资产对应，那么就只有在数字版和实物版之间有明确的联系时，智能合约才能发挥作用。比如说房子，在房子的数字版所有权发生变化时，房子实物版的所有权也必须跟着改变。我们需要让数字世界“了解”实物世界，这被称为“神谕问题（Oracle problem）”。  
在 A 把房子交给 B 时，智能合约需要知道他是真的把房子交给 B 了。实现方式很多，但本质上都是一样的，都需要在实物世界中找一个可信的第三方验证这些事件。

比如说，这个房子在以太坊中被表示成了一个不可替代的代币Token。A 可以在一个原子交换中用房子跟 B 换一些以太币。那么问题来了，B 需要相信那个代币真的代表那个房子。这需要靠某种神谕来保证，将代表房子的代币交给他后，真的可以表示那个房子在法律上是属于他的。  

进一步说，**即便政府机构承认那个代币真的可以代表那个房子，如果这个代币被偷了怎么办？房子属于那个偷代币的贼吗？如果代币丢了怎么办？房子就没法再卖了吗？还能再重新发一个代币给这个房子吗？如果可以，由谁来发呢？**   

按照全面去中心化的思想，你资产的唯一凭证就是你的秘钥，秘钥丢失意味着资产归零，而且不可篡改，不可逆；但这显然是大部分人无法接受的，任何试图挽回损失的措施都是与去中心化背道而驰的，这是十分矛盾的行为，可以参考以太坊的硬分叉。

不管是水果、汽车还是房子，要将数字资产与实物资产连接起来都是个难题，至少在去中心化的上下文中特别不好实现。**实物资产是由你所在的司法系统监管的，除了你创建的智能合约之外，他们还相信别的一些东西。也就是说智能合约中的所有权不一定能代表实物世界中的所有权，它跟普通合约一样存在信任问题。需要信任第三方的智能合约失去了自己最大的优势，不再是去信任化的合约。**

即便是电子书、医疗记录或电影这样的数字资产，也会遇到同样的问题。对这些数字资产的“权益”最终都是由某个权威机构决定的，而我们需要信任他们的神谕。

就此而言，神谕只是简化版的法官。所以实际上你得到并不是只有机器执行的合约和简化的约束，而是掺杂了主观认识和人为判断风险的代码，而且这些代码要实现所有可能的情况，很复杂。换句话说，为了让合约变得“智能”，编写代码的复杂性急剧升高，**但你还是没办法摆脱对某个人的信任。**


## 版权保护

版权保护是区块链被吹捧的另一个应用领域，模式通常为：  

> 利用区块链做一个自有版权的平台（内容可以是音乐、文字、视频等），原创者可以直接发布其作品，用户支付相应的费用浏览内容，所支付的费用直接转给原创者，不经过中心化的平台；而且利用区块链技术可以溯源防伪……

与上面提到的公示公证不同的是，通过在线平台发布的作品直接完成了作品 **信息化**，并保证了作品的 **有效性**（信息源在线上而非线下）。所以通过区块链，可以保障每个作品都是有效且无法被篡改的，但是要实现作品的版权保护，又会有一些新的问题。

这种模式解决的痛点为：  
1\.  用区块链不可篡改的特性进行溯源防伪  
2\.  原创者与用户点对点对接，跳过中心化平台的抽成，保障原创者的权益  

出发点很好，但是我们细细分析还是有些问题的。版权其实分为署名权和分发权（信息网络传播权）两方面，而这两方面正好对应上述两点。   

### 署名权

对于第一点署名权，区块链的不可篡改性确实可以用来保护版权

> 当一个作品在区块链平台上发布时，它就有了区块链上的标识（这个标识就是身份识别信息，包含加密密钥、原文件地址等、付费信息、使用次数、作者等等信息），这个标识不会因被拷贝而丢失（反而会记录拷贝这个行为）；当这个拷贝文件被放置在另外一个平台时，一旦文件被使用，有以下两个情况：1、这个平台不支持区块链，所以无法识别该文件（就是无法播放）。在这个过程中，该文件会自动寻找原区块链平台，向使用者发出询问，输入这个产品的个人密钥，是否要付费使用该文件（或向这个平台授权等）。但该平台有可能屏蔽这个过程，也就是，该平台会认为这是一个病毒文件，根本就不让打开；2、如果这个平台支持区块链，这个标识就会走识别能不能授权播放（也就是需不需要付费使用）的流程。

但这里有个问题，比如对于文字资料，某个用户直接将文章的文字内容拷贝下来，或者记录下来（不是拷贝文件而是直接拷贝内容），然后用普通文稿的形式发布到另一个普通的平台上。对于这种行为，除非通过用户举报，否则是无法发现的。当然这些例子有些极端，但也说明区块链的版权保护也不是万能的；而且用现有技术也能重复内容比对，防拷贝等。也就是说 **区块链能做到的，现有技术也能做到，现有技术做不到的，区块链也做不到** ，并且如前面所说，用区块链来做版权保护，其实成本更高。

### 分发权

在大部分人眼中，版权=署名权，反而忽视了问题更大的分发权。举个例子，现在流行的短视频平台抖音，抖音上面的用户发的视频都有自己ID的水印，这是抹不掉的，相当于署名权完全在原创用户手中，但是你在抖音上面看到什么样的短视频，这完全由其推荐算法决定。这也是现在流行的信息流，这个地方就很有趣了，你相当于把作品的分发权交给了平台，那么这样做有什么后果呢？或者说平台可以怎么利用你的分发权来赚钱呢？

1.  流量入口的转移   
    以往用户看到一个好的作品需要去关注原创者（比如某个原创歌手），然后从该歌手那里才能获得后续的更新，这时候流量入口在原创者那里，有了流量就有收益，而且流量也涉及到原创者的发展方向。但现在用户只需要打开APP，就可以看到关注歌手的更新、动态资讯等，用户要只需要浏览平台APP给你推荐的内容就可以了。  

    这个时候用户由依赖原创者转变为依赖平台，流量入口转移到了平台那里，收益自然也转移了。原创者虽然也有分成，但是大头利润被平台赚取，且原创者的发展受制于平台，平台算法推荐的少，该原创者的关注度自然就下降了。  

    而且单个原创者的作品有限，但是平台聚合了大量的原创者，利用他们作品的分发权，可以产生更大的流量，让你沉迷其中。想想你每天沉迷的是头条，是抖音还是里面的某几个大V？   

2.  流量干扰   
    因为机器推荐算法是单向的，当你习惯了沉迷在每日的推送中时，你会默认接受其中的内容，除非引起强烈不适。而**流量干扰，则是平台可以在推荐给你的信息流中夹杂一些其他东西**，比如广告，比如一些低质量的内容，或者一些花钱上位的内容。只要推送主体还是你喜欢的，对于这些流量干扰，你是不会介意的。而这些流量干扰有一个fashion的名字叫做信息流广告，经常出现在各大公司的财报中，目前是很多公司的主要利润和利润增长来源。  

    由于流量入口的转移，原本可以附加于原创者的增值内容也都转移到了平台上，留给原创者的只是少得可怜的分成。

再举个例子，实体书店也会有推荐、促销活动，那和依赖推荐算法的平台有什么区别？    

**区别在于实体书店你除了能看到推荐书籍，其余书都能看到；但是推荐算法是把它认为你喜欢的书硬塞给你，请你一条一条浏览，其余的呢？没有其余的！你“只能”看他推荐给你的，算法甚至可以将每本书里的内容单独抽出来，然后整合在一起推荐给你，这样就更进一步模糊作品的归属，将用户的注意力转移到平台的推荐内容。**

从上面的分析我们可以看到，现有技术可以保障署名权，但是无法保障涉及利益的分发权，而且区块链也做不到。 

或许你可以说用区块链做一个没有推荐算法的版权保护平台不就行了？可那不是回到了各平台早期没有推荐算法比较落后的模式了？

你又可以说用智能合约做一个透明的纯粹的推荐算法，但这个平台怎么盈利呢？一个行业只有有持续的利润才能不断地发展，而马克思说过：

> 为了100%的利润,资本就敢践踏一切人间法律。

版权保护的痛点在于发展模式和经营模式，这些其实和技术没有太大关系。

### 升华

我们进一步分析，平台通过信息流广告霸占了巨额利润么？剥削了原创者么？

分析过程可能会颠覆某些人的三观，在此省略，我们只看结论：

短期来看，确实是这样。但是从长期来看，

> 各行各业都有平均利润率，利润太高会导致竞争对手加入，并摊薄利润。

由于竞争，信息流所带来的暴利不会持续太久，竞争的结果是把利润返回给了消费用户。

> 消费者剩余，是属于消费者的。

结局是低质量原创者剥削了高质量原创者。

Ref  
1.  [恶的土壤，结不出善的头条](https://mp.weixin.qq.com/s/UX0J7uN08-ASuVnijKSijQ)  
2.  [携程提价，该不该谴责](https://mp.weixin.qq.com/s/32FdhFbkJ-hEtGIec8UdkA)