# Bitcoin

- [Bitcoin](#bitcoin)
  - [Utilities](#utilities)
  - [Blockchain API and Web services](#blockchain-api-and-web-services)
  - [Wallets API](#wallets-api)
  - [Open Source Wallets](#open-source-wallets)
  - [Blockchain Explorers](#blockchain-explorers)
  - [Libraries](#libraries)
    - [C++ Libraries](#c-libraries)
    - [JavaScript Libraries](#javascript-libraries)
    - [PHP Libraries](#php-libraries)
    - [Ruby Libraries](#ruby-libraries)
    - [Python Libraries](#python-libraries)
    - [Java Libraries](#java-libraries)
    - [.Net Libraries](#net-libraries)
  - [Playgrounds](#playgrounds)
  - [Blockchain dump](#blockchain-dump)
  - [Full nodes](#full-nodes)
  - [Blockchain Books](#blockchain-books)

## Utilities

-   [BitKey](https://bitkey.io) - Live USB for airgapped transactions and Bitcoin swiss army knife 
-   [Pycoin](https://github.com/richardkiss/pycoin) Python-based Bitcoin and alt-coin utility library.
-   [sx](https://github.com/spesmilo/sx/) - sx - command line Bitcoin to empower the sysadmin
-   [bx](https://github.com/libbitcoin/libbitcoin-explorer) - Bitcoin Command Line Tool
-   [txwatcher](https://github.com/tsileo/txwatcher) - A little Python utility that lets you monitor Bitcoin addresses through Blockchain Websocket API and perform custom callbacks.
-   [hellobitcoin](https://github.com/prettymuchbryce/hellobitcoin) - A collection of simple programs which can generate bitcoin wallets, create and sign transactions, and send transactions over the bitcoin network.
-   [Mining visualization](http://www.yogh.io/#mine:last)

## Blockchain API and Web services

-   [block.io](https://block.io)
-   [BlockCypher](http://www.blockcypher.com)
-   [Gem.co](https://gem.co)
-   [Insight](https://insight.is)
-   [Chain.com](https://chain.com)
-   [Toshi by Coinbase](https://toshi.io/)
-   [Smartbit](https://www.smartbit.com.au)
-   [Cashier-BTC](https://github.com/Overtorment/Cashier-BTC) - self-hosted payment gateway.
-   [Chainradar API](https://github.com/yasaricli/chainradar-api) - Blockchain Explorer API for Chainradar

## Wallets API

-   [BitGo](https://www.bitgo.com/api/)
-   [Coinbase](https://developers.coinbase.com)
-   [Blockchain.info](https://blockchain.info/api)
-   [BIP32](http://bip32.org)

## Open Source Wallets

-   [CoPay by BitPay](https://copay.io/)
-   [CoinPunk](https://coinpunk.com/)
-   [Coinb.in](https://coinb.in)
-   [Electrum](https://electrum.org/)

## Blockchain Explorers

-   [Chain.so](http://chain.so)
-   [Blockchain.info](https://blockchain.info)
-   [BlockTrail](https://www.blocktrail.com/BTC) 
-   [Bitcoin Transaction Explorer](https://github.com/JornC/bitcoin-transaction-explorer)
-   [Blockexplorer.com](https://blockexplorer.com)
-   [Smartbit](https://www.smartbit.com.au)
-   [Bitkit](https://bitkit.live) - Real time transaction updates

## Libraries

### C++ Libraries

-   [Libbitcoin](https://libbitcoin.org/)
-   [libwally-core](https://github.com/ElementsProject/libwally-core)
-   [secp256k1](https://github.com/bitcoin-core/secp256k1)

### JavaScript Libraries

-   [Awesome CryptoCoinJS](https://github.com/cryptocoinjs/awesome-cryptocoinjs)
-   [Bitcore Library](https://github.com/bitpay/bitcore-lib)
-   [Bitcoinjs-lib](https://github.com/bitcoinjs/bitcoinjs-lib)
-   [Cryptocoin](https://github.com/cryptocoinjs/cryptocoin)
-   [BlockTrail SDK NodeJS](https://github.com/blocktrail/blocktrail-sdk-nodejs)
-   [bcoin](https://github.com/bcoin-org/bcoin) - Javascript bitcoin library for node.js and browsers 

### PHP Libraries

-   [PHP-OP_RETURN](https://github.com/coinspark/php-OP_RETURN)
-   [BlockTrail PHP SDK](https://github.com/blocktrail/blocktrail-sdk-php)

### Ruby Libraries

-   [Bitcoin-ruby](https://github.com/lian/bitcoin-ruby)

### Python Libraries

-   [BlockTrail SDK Python](https://github.com/blocktrail/blocktrail-sdk-python)
-   [btctxstore](https://github.com/F483/btctxstore) - simple library to store/retrieve information in bitcoin transactions using OP_RETURN
-   [pybitcointools](https://github.com/vbuterin/pybitcointools) - Python library for Bitcoin signatures and transactions from Vitalik Buterin. Project discontinued.
-   [pycoin](https://github.com/richardkiss/pycoin) - Python library for Bitcoin keys, signatures, transactions. Includes full VM implementation and tools for manipulating keys (ku) and transactions (tx).
-   [bitcoin_tools](https://github.com/sr-gi/bitcoin_tools) - Python library for building and analyzing transactions and scripts (both standard and custom). Comes along with a UTXO set analysis tool. Includes several examples and exhaustive documentation. 

### Java Libraries

-   [BitcoinJ](https://bitcoinj.github.io)
-   [XChange](https://github.com/timmolter/XChange) - Library that provides a simple and consistent API for interacting with 50+ Bitcoin currency exchanges.

### .Net Libraries

-   [NBitcoin](https://github.com/MetacoSA/NBitcoin) - Comprehensive Bitcoin library for the .NET framework.
-   [BitcoinLib](https://github.com/GeorgeKimionis/BitcoinLib) - The most complete, up-to-date, battle-tested .net Library and RPC Wrapper for Bitcoin and Altcoins in C#.
-   [QBitNinja](https://github.com/MetacoSA/QBitNinja) - An Open Source and powerful blockchain API

## Playgrounds

-   [Script Playground](http://www.crmarsh.com/script-playground/)
-   [Bitcoin IDE](https://github.com/siminchen/bitcoinIDE) - Bitcoin Script for dummies
-   [Debug Script Execution](https://webbtc.com/script)
-   [Script Debugger](https://github.com/kallewoof/btcdeb)
-   [Bitcore Playground](https://bitcore.io/playground/)
-   [Mnemonic Code generator](https://dcpos.github.io/bip39/)
-   [blockchain-demo](https://github.com/anders94/blockchain-demo/) - A web-based demonstration of blockchain concepts
-   [Bitcoin Script Debugger](https://github.com/liuhongchao/bitcoin4s) - Visualize Bitcoin script execution for real transactions

## Blockchain dump

-   [WebBTC](http://dumps.webbtc.com/bitcoin/) - These are postgres database dumps of the bitcoin-ruby-blockchain database generated by webbtc.com.
-   [BitcoinDatabaseGenerator](https://github.com/ladimolnar/BitcoinDatabaseGenerator) - A high performance data transfer tool that can be used to copy data from Bitcoin Core blockchain files to a SQL Server database
-   [Blockparser+SQL](https://github.com/mcdee/blockparser) - Fast, quick and dirty bitcoin blockchain parser
-   [BitcoinABE](https://github.com/bitcoin-abe/bitcoin-abe) - Abe: block browser for Bitcoin and similar currencies
-   [NBitcoin.Indexer](https://github.com/MetacoSA/NBitcoin.Indexer) - Scalable and fault-tolerant block chain indexer for Azure cloud platform.
-   [Blockchain2Graph](https://github.com/straumat/blockchain2graph) - Graph Database Builder

## Full nodes

-   [Bitcoinjs-server](https://github.com/bitcoinjs/bitcoinjs-server) - Bitcoin network node in JavaScript using Node.js / LevelDB
-   [Bitcoin-ruby-node](https://github.com/mhanne/bitcoin-ruby-node) - bitcoin node based on bitcoin-ruby-blockchain
-   [Toshi by Coinbase](https://toshi.io/) - An open source Bitcoin node built to power large scale web applications
-   [Fullnode](https://github.com/ryanxcharles/fullnode) - Javascript implementation of bitcoin
-   [Insight API](https://github.com/bitpay/insight-api) - A bitcoin blockchain API for web wallets
-   [Bitcoind.JS](https://github.com/bitpay/bitcoind.js) - bitcoind linked to node.js by BitPay
-   [Bitcore](https://github.com/bitpay/bitcore) - Formerly just a Nodejs library, now a full node

## Blockchain Books

-   [Anonymous Cryptocurrencies: The rise of bitcoin alternatives that offer true anonymity](https://www.amazon.com/Cryptocurrencies-bitcoin-alternatives-offer-anonymity/dp/1500682586/ref=pd_sim_14_24?_encoding=UTF8&pd_rd_i=1500682586&pd_rd_r=PMB5GABNHVFM2VHE3WBH&pd_rd_w=6yGsW&pd_rd_wg=yVxm8&psc=1&refRID=PMB5GABNHVFM2VHE3WBH) - Will Martin
-   [Bit by Bit: How P2P Is Freeing the World](https://www.amazon.com/Bit-How-P2P-Freeing-World-ebook/dp/B00S085TRS/ref=sr_1_1?ie=UTF8&qid=1476985273&sr=8-1&keywords=Bit+by+Bit) - Jeffery Tucker
-   [Bitcoin : A Complete Beginner's Guide - Master The Game](https://www.amazon.com/Bitcoin-Complete-Beginners-Guide-Master-ebook/dp/B01JU6KD9C/ref=sr_1_2?ie=UTF8&qid=1476986332&sr=8-2&keywords=The+Bitcoin+Tutorial%3A) - Luke Sutton
-   [Bitcoin Basics](https://www.amazon.com/Bitcoin-Basics-Creating-Investing-Bitcoins/dp/1508478945/ref=pd_sim_14_4?_encoding=UTF8&pd_rd_i=1508478945&pd_rd_r=YMYPCM376H2JNJ9NVB6D&pd_rd_w=0gtr5&pd_rd_wg=iqdC9&psc=1&refRID=YMYPCM376H2JNJ9NVB6D) - Benjamin Tideas
-   [Bitcoin Decoded: Bitcoin Beginner's Guide to Mining and the Strategies to Make Money with Cryptocurrencies](https://www.amazon.com/Bitcoin-Decoded-Beginners-Strategies-Cryptocurrencies/dp/061595524X/ref=pd_sim_14_12?_encoding=UTF8&pd_rd_i=061595524X&pd_rd_r=KF66S03S94P6CMSN0K29&pd_rd_w=Dibne&pd_rd_wg=jRGoU&psc=1&refRID=KF66S03S94P6CMSN0K29) -  Brett Combs,Tom Mitsoff
-   [Bitcoin For Dummies](https://www.amazon.com/Bitcoin-Dummies-Prypto/dp/1119076137/ref=pd_sim_14_30?_encoding=UTF8&pd_rd_i=1119076137&pd_rd_r=26RQGPJBS5V65WXKFS9Z&pd_rd_w=DJMVN&pd_rd_wg=E1guu&psc=1&refRID=26RQGPJBS5V65WXKFS9Z) - Prypto
-   [Bitcoin Internals: A Technical Guide to Bitcoin](https://www.amazon.com/Bitcoin-Internals-Technical-Guide-ebook/dp/B00DG8EPT0/ref=sr_1_1?ie=UTF8&qid=1476985144&sr=8-1&keywords=Bitcoin+Internals%3A) - Chris Clark
-   [Bitcoin Step by Step for Beginners: How to Invest and Profit from Bitcoin Today!](https://www.amazon.com/Bitcoin-Step-Beginners-Invest-Profit-ebook/dp/B00K5RUKEE/ref=sr_1_1?ie=UTF8&qid=1476986366&sr=8-1&keywords=Bitcoin+Step+by+Step) - Leo Kallstrom
-   [Bitcoin The Future of Money](https://www.amazon.com/Bitcoin-future-money-Dominic-Frisby/dp/1783521023/ref=pd_sim_14_19?_encoding=UTF8&pd_rd_i=1783521023&pd_rd_r=KF66S03S94P6CMSN0K29&pd_rd_w=Dibne&pd_rd_wg=jRGoU&psc=1&refRID=KF66S03S94P6CMSN0K29) - Dominic Frisby
-   [Bitcoin and Cryptocurrency Technologies: A Comprehensive Introduction](https://www.amazon.com/Bitcoin-Cryptocurrency-Technologies-Comprehensive-Introduction/dp/0691171696/ref=pd_sim_14_8?_encoding=UTF8&pd_rd_i=0691171696&pd_rd_r=0CHWWTBSREYE58R7P0SX&pd_rd_w=gCU04&pd_rd_wg=gZavr&psc=1&refRID=0CHWWTBSREYE58R7P0SX) - Arvind Narayanan,Joseph Bonneau,Edward Felten, Andrew Miller,Steven Goldfeder ([free version of first draft](https://d28rh4a8wq0iu5.cloudfront.net/bitcointech/readings/princeton_bitcoin_book.pdf?a=1))
-   [Bitcoin and The Future of Money](https://www.amazon.com/Bitcoin-Future-Money-Jose-Pagliery/dp/1629370363/ref=pd_sim_14_14?_encoding=UTF8&pd_rd_i=1629370363&pd_rd_r=NHZ4SY5ACXYYFA2FN5PK&pd_rd_w=WI1XD&pd_rd_wg=LtNFM&psc=1&refRID=NHZ4SY5ACXYYFA2FN5PK) - Jose Pagliery
-   [Bitcoin for the Befuddled](https://www.amazon.com/Bitcoin-Befuddled-Conrad-Barski/dp/1593275730/ref=pd_sim_14_8?_encoding=UTF8&pd_rd_i=1593275730&pd_rd_r=KF66S03S94P6CMSN0K29&pd_rd_w=Dibne&pd_rd_wg=jRGoU&psc=1&refRID=KF66S03S94P6CMSN0K29) - Conrad Barski and Chris Wilmer
-   [Bitcoin in English](https://www.amazon.com/Bitcoin-English-Understanding-HOW-Works-ebook/dp/B00X09LBX8/ref=sr_1_1?ie=UTF8&qid=1476985191&sr=8-1&keywords=Bitcoin+in+English) - Peter H Le
-   [Bitcoin: Mastering Bitcoin & Cyptocurrency for Beginners](https://www.amazon.com/Bitcoin-Mastering-Cyptocurrency-Reinventing-Currencies/dp/153342733X/ref=pd_sim_14_6?_encoding=UTF8&pd_rd_i=153342733X&pd_rd_r=TJJ3Y2F85RACYQSF23GZ&pd_rd_w=kwfLQ&pd_rd_wg=koGbV&psc=1&refRID=TJJ3Y2F85RACYQSF23GZ) - Tim Harris
-   [Digital Gold: The Untold Story of Bitcoin](https://www.amazon.com/Digital-Gold-Bitcoin-Millionaires-Reinvent/dp/0062362496/ref=pd_sim_14_1?_encoding=UTF8&pd_rd_i=0062362496&pd_rd_r=D7KMJCP493PPH9ADVPCR&pd_rd_w=g5Hrb&pd_rd_wg=KsfK5&psc=1&refRID=D7KMJCP493PPH9ADVPCR) -  Nathaniel Popper
-   [Everything you need to know about buying, selling and investing in Bitcoin](https://www.amazon.com/Everything-selling-investing-Bitcoin-Technology/dp/1493699474/ref=pd_sim_14_17?_encoding=UTF8&pd_rd_i=1493699474&pd_rd_r=KF66S03S94P6CMSN0K29&pd_rd_w=Dibne&pd_rd_wg=jRGoU&psc=1&refRID=KF66S03S94P6CMSN0K29) - A. H Smithers
-   [Mastering Bitcoin: Unlocking Digital Cryptocurrencies](https://www.amazon.com/Mastering-Bitcoin-Unlocking-Digital-Cryptocurrencies/dp/1449374042/ref=sr_1_1?ie=UTF8&qid=1476978890&sr=8-1&keywords=Mastering+Bitcoin%3A+Unlocking+Digital+Cryptocurrencies) Andreas M.  Antonopoulos
-   [The Age of Cryptocurrency: How Bitcoin and Digital Money are challenging the Global Economic Order](https://www.amazon.com/Age-Cryptocurrency-Bitcoin-Challenging-Economic/dp/1250065631/ref=pd_sim_14_6?_encoding=UTF8&pd_rd_i=1250065631&pd_rd_r=7XN6AJY2PX75QDZTZAPM&pd_rd_w=ZDHwi&pd_rd_wg=oQ9Te&psc=1&refRID=7XN6AJY2PX75QDZTZAPM) - Paul Vigna and Michael J. Casey
-   [The Anatomy of a Money-Like Informational Commodity: A study of Bitcoin](https://www.amazon.com/Anatomy-Money-like-Informational-Commodity-Bitcoin-ebook/dp/B00MEAO7XK/ref=sr_1_1?ie=UTF8&qid=1476985224&sr=8-1&keywords=The+Anatomy+of+a+Money) - Tim Swanson
-   [The Bitcoin Bible](https://www.amazon.com/Bitcoin-Bible-Gold-Benjamin-Guttmann/dp/3732296962/ref=pd_sim_14_18?_encoding=UTF8&pd_rd_i=3732296962&pd_rd_r=KF66S03S94P6CMSN0K29&pd_rd_w=Dibne&pd_rd_wg=jRGoU&psc=1&refRID=KF66S03S94P6CMSN0K29) - Benjamin Guttmann
-   [The Bitcoin Standard](https://www.amazon.com/Bitcoin-Standard-Decentralized-Alternative-Central/dp/1119473861) - Saifedean Ammous
-   [The Bitcoin Big Bang: How Alternative Currencies Are About to Change the World](https://www.amazon.com/Bitcoin-Big-Bang-Alternative-Currencies/dp/1118963660/ref=pd_sim_14_13?_encoding=UTF8&pd_rd_i=1118963660&pd_rd_r=KF66S03S94P6CMSN0K29&pd_rd_w=Dibne&pd_rd_wg=jRGoU&psc=1&refRID=KF66S03S94P6CMSN0K29) - Brian Kelly
-   [The Bitcoin Tutor: Unlocking the Secrets of Bitcoin](https://www.amazon.com/Bitcoin-Tutor-Unlocking-Secrets/dp/0979864917/ref=pd_sim_14_5?_encoding=UTF8&pd_rd_i=0979864917&pd_rd_r=QZN41AYGXJSCS7Q32WA7&pd_rd_w=2i7o1&pd_rd_wg=nbCJJ&psc=1&refRID=QZN41AYGXJSCS7Q32WA7) - Marc A. Carignan
-   [The Bitcoin Tutorial: Develop an intuitive understanding of the currency and blockchain technology](https://www.amazon.com/Bitcoin-Tutorial-understanding-blockchain-technology-ebook/dp/B01EP9SVE8/ref=sr_1_1?ie=UTF8&qid=1476986332&sr=8-1&keywords=The+Bitcoin+Tutorial%3A) - Bruce Kleinman
-   [The Black Book of Bitcoin: A Step-by-Step Bitcoin Guide on Everything You Need to Know About this New Currency](https://www.amazon.com/Black-Book-Bitcoin-Step-Step/dp/1519284527/ref=pd_sim_14_22?_encoding=UTF8&pd_rd_i=1519284527&pd_rd_r=PMB5GABNHVFM2VHE3WBH&pd_rd_w=6yGsW&pd_rd_wg=yVxm8&psc=1&refRID=PMB5GABNHVFM2VHE3WBH) - Mark Janniro
-   [The Book of Satoshi](https://www.amazon.com/Book-Satoshi-Collected-Writings-Nakamoto/dp/0996061312/ref=pd_sim_14_8?_encoding=UTF8&pd_rd_i=0996061312&pd_rd_r=9QB4ZB20S6CY4NGE029X&pd_rd_w=2TjP2&pd_rd_wg=VjLqC&psc=1&refRID=9QB4ZB20S6CY4NGE029X) - Paul Champagne
-   [The Digital Money Game: Competing in the multi-trillion dollar payments industry](https://www.amazon.com/Digital-Money-Game-Competing-multi-trillion-ebook/dp/B00LZ3T66K/ref=sr_1_1?ie=UTF8&qid=1476985249&sr=8-1&keywords=The+Digital+Money+Game%3A) - Charmaine Oak
-   [The Internet of Money - Andreas M Antonopoulos](https://www.amazon.com/Internet-Money-Andreas-M-Antonopoulos/dp/1537000454/ref=pd_bxgy_14_img_2?_encoding=UTF8&pd_rd_i=1537000454&pd_rd_r=XPR2XE7MNFCYAB70VZDM&pd_rd_w=xn5TU&pd_rd_wg=4Sqi0&psc=1&refRID=XPR2XE7MNFCYAB70VZDM)
-   [Understanding Bitcoin: Cryptography, Engineering and Economics](https://www.amazon.com/Understanding-Bitcoin-Cryptography-Engineering-Economics/dp/1119019168/ref=pd_sim_14_16?_encoding=UTF8&pd_rd_i=1119019168&pd_rd_r=KF66S03S94P6CMSN0K29&pd_rd_w=Dibne&pd_rd_wg=jRGoU&psc=1&refRID=KF66S03S94P6CMSN0K29) - Pedro Franco
-   [Virtual Billions: The Genius, the Drug Lord, and the Ivy League Twins behind the Rise of Bitcoin](https://www.amazon.com/Virtual-Billions-Genius-League-Bitcoin/dp/163388144X/ref=sr_1_1?ie=UTF8&qid=1476986258&sr=8-1&keywords=Virtual+Billions%3A+The+Genius) - Eric Geissinger
-   [Wildcat Currency](https://www.amazon.com/Wildcat-Currency-Virtual-Revolution-Transforming/dp/0300186134/ref=sr_1_1?ie=UTF8&qid=1476986207&sr=8-1&keywords=Wildcat+Currency) - Edward Castronova
